package com.dbnt.faisp.equip.mapper;

import com.dbnt.faisp.equip.model.Equip;
import com.dbnt.faisp.equip.model.EquipLog;
import com.dbnt.faisp.util.ParamMap;

import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface EquipMapper {

	List<ParamMap> selectEquipStatus(Equip equip);

	List<Equip> selectEquipList(Equip equip);

	Integer selectEquipListCnt(Equip equip);

	Equip selectEquipInfo(Equip equip);

	ParamMap selectEduType(Equip equip);

	Equip selectHistoryDetail(Equip equip);

	List<EquipLog> selectEquipLogList(EquipLog equipLog);

	Integer selectEquipLogListCnt(EquipLog equipLog);

	String selectEquipFirstId(Equip equip);



}
